@@ -22,11 +22,6 @@ class SubGroupInline(admin.TabularInline):
     extra = 0
 
 
-class SpaceInline(admin.TabularInline):
-    model = Space
-    extra = 0
-
-
 class HouseAdmin(admin.ModelAdmin):
     list_display = ('number', 'fase', 'parent', 'subgroup', 'house_type', 'garden', 'status')
     list_filter = ['fase', 'parent', 'subgroup', 'status', 'house_type']
@@ -48,7 +43,7 @@ class HouseTypeAdmin(admin.ModelAdmin):
 
 
     inlines = [
-        HouseInline, SpaceInline
+        HouseInline
     ]
 
 
